package permissions.dispatcher.processor.data;

public final class Source {

    public static final String[] EMPTY = {};

    public static class OnePermissionActivity {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.CAMERA)",
                "void showRationaleForCamera() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, \"android.permission.CAMERA\")) {",
                "      target.showCamera();",
                "    } else {",
                "      if (ActivityCompat.shouldShowRequestPermissionRationale(target, \"android.permission.CAMERA\")) {",
                "        target.showRationaleForCamera();",
                "      }",
                "      ActivityCompat.requestPermissions(target, new String[]{\"android.permission.CAMERA\"}, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, String[] permissions, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class OnePermissionFragment {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Fragment;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainFragment extends Fragment {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.CAMERA)",
                "void showRationaleForCamera() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainFragmentPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainFragment target) {",
                "    if (PermissionUtils.hasSelfPermissions(target.getActivity(), \"android.permission.CAMERA\")) {",
                "      target.showCamera();",
                "    } else {",
                "      if (ActivityCompat.shouldShowRequestPermissionRationale(target.getActivity(), \"android.permission.CAMERA\")) {",
                "        target.showRationaleForCamera();",
                "      }",
                "      ActivityCompat.requestPermissions(target.getActivity(), new String[]{\"android.permission.CAMERA\"}, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainFragment target, int requestCode, String[] permissions, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class TwoPermissions {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "import permissions.dispatcher.ShowsRationales;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@NeedsPermissions({Manifest.permission.READ_CONTACTS, Manifest.permission.WRITE_CONTACTS})",
                "void showContact() {",
                "}",
                "@ShowsRationale(Manifest.permission.CAMERA)",
                "void showRationaleForCamera() {",
                "}",
                "@ShowsRationales({Manifest.permission.READ_CONTACTS, Manifest.permission.WRITE_CONTACTS})",
                "void showRationaleForContact() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final int REQUEST_SHOWCONTACT = 1;",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, \"android.permission.CAMERA\")) {",
                "      target.showCamera();",
                "    } else {",
                "      if (ActivityCompat.shouldShowRequestPermissionRationale(target, \"android.permission.CAMERA\")) {",
                "        target.showRationaleForCamera();",
                "      }",
                "      ActivityCompat.requestPermissions(target, new String[]{\"android.permission.CAMERA\"}, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void showContactWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, new String[] {\"android.permission.READ_CONTACTS\", \"android.permission.WRITE_CONTACTS\"})) {",
                "      target.showContact();",
                "    } else {",
                "      if (PermissionUtils.shouldShowRequestPermissionRationale(target, new String[] {\"android.permission.READ_CONTACTS\", \"android.permission.WRITE_CONTACTS\")) {",
                "        target.showRationaleForContact();",
                "      }",
                "      ActivityCompat.requestPermissions(target, new String[] {\"android.permission.READ_CONTACTS\", \"android.permission.WRITE_CONTACTS\"}, REQUEST_SHOWCONTACT);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, String[] permissions, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      case REQUEST_SHOWCONTACT:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showContact();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class NoShowRationale {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@NeedsPermissions({Manifest.permission.READ_CONTACTS, Manifest.permission.WRITE_CONTACTS})",
                "void showContact() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private static final int REQUEST_SHOWCONTACT = 1;",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, \"android.permission.CAMERA\")) {",
                "      target.showCamera();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, new String[]{\"android.permission.CAMERA\"}, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void showContactWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, new String[] {\"android.permission.READ_CONTACTS\", \"android.permission.WRITE_CONTACTS\"})) {",
                "      target.showContact();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, new String[] {\"android.permission.READ_CONTACTS\", \"android.permission.WRITE_CONTACTS\"}, REQUEST_SHOWCONTACT);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, String[] permissions, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      case REQUEST_SHOWCONTACT:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showContact();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class OnePermissionAndOtherRationale {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.READ_CONTACTS)",
                "void showRationaleForCamera() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, \"android.permission.CAMERA\")) {",
                "      target.showCamera();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, new String[]{\"android.permission.CAMERA\"}, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, String[] permissions, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class OnePermissionAndOtherRationales {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationales;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showCamera() {",
                "}",
                "@ShowsRationales({Manifest.permission.READ_CONTACTS})",
                "void showRationaleForCamera() {",
                "}",
                "}"};

        public static final String[] EXPECT = {
                "package permissions.dispatcher.sample;",
                "\n",
                "import android.support.v4.app.ActivityCompat;",
                "import java.lang.String;",
                "import permissions.dispatcher.PermissionUtils;",
                "\n",
                "public final class MainActivityPermissionsDispatcher {",
                "  private static final int REQUEST_SHOWCAMERA = 0;",
                "\n",
                "  private MainActivityPermissionsDispatcher() {",
                "  }",
                "\n",
                "  public static void showCameraWithCheck(MainActivity target) {",
                "    if (PermissionUtils.hasSelfPermissions(target, new String[]{\"android.permission.CAMERA\"})) {",
                "      target.showCamera();",
                "    } else {",
                "      ActivityCompat.requestPermissions(target, new String[]{\"android.permission.CAMERA\"}, REQUEST_SHOWCAMERA);",
                "    }",
                "  }",
                "\n",
                "  public static void onRequestPermissionsResult(MainActivity target, int requestCode, String[] permissions, int[] grantResults) {",
                "    switch (requestCode) {",
                "      case REQUEST_SHOWCAMERA:",
                "      if (PermissionUtils.verifyPermissions(grantResults)) {",
                "        target.showCamera();",
                "      }",
                "      break;",
                "      default:",
                "      break;",
                "    }",
                "  }",
                "}"
        };
    }

    public static class ZeroPermission {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "}"};
    }

    public static class WrongClassName {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainUtils {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.CAMERA)",
                "void showRationaleForCamera() {",
                "}",
                "}"};
    }

    public static class DuplicatedPermission {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showContact() {",
                "}",
                "}"};
    }

    public static class DuplicatedPermissions {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showCamera() {",
                "}",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showContact() {",
                "}",
                "}"};
    }

    public static class DuplicatedRationale {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.READ_CONTACTS)",
                "void showContact() {",
                "}",
                "@ShowsRationale(Manifest.permission.READ_CONTACTS)",
                "void showRationaleForContact() {",
                "}",
                "}"};
    }

    public static class DuplicatedRationales {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationales;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "void showCamera() {",
                "}",
                "@ShowsRationales({Manifest.permission.READ_CONTACTS})",
                "void showContact() {",
                "}",
                "@ShowsRationales({Manifest.permission.READ_CONTACTS})",
                "void showRationaleForContact() {",
                "}",
                "}"};
    }

    public static class NeedsPermissionIsPrivate {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "private void showCamera() {",
                "}",
                "}"};
    }

    public static class NeedsPermissionsIsPrivate {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "private void showCamera() {",
                "}",
                "}"};
    }

    public static class ShowsRationaleIsPrivate {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermission;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationale;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermission(Manifest.permission.CAMERA)",
                "private void showCamera() {",
                "}",
                "@ShowsRationale(Manifest.permission.CAMERA)",
                "void showRationaleForCamera() {",
                "}",
                "}"};
    }

    public static class ShowsRationalesIsPrivate {
        public static final String[] ACTUAL = {
                "package permissions.dispatcher.sample;",
                "import android.Manifest;",
                "import android.app.Activity;",
                "import android.os.Bundle;",
                "import android.view.Menu;",
                "import android.view.MenuItem;",
                "import permissions.dispatcher.NeedsPermissions;",
                "import permissions.dispatcher.RuntimePermissions;",
                "import permissions.dispatcher.ShowsRationales;",
                "@RuntimePermissions",
                "public class MainActivity extends Activity {",
                "@NeedsPermissions({Manifest.permission.CAMERA})",
                "private void showCamera() {",
                "}",
                "@ShowsRationales({Manifest.permission.CAMERA})",
                "void showRationaleForCamera() {",
                "}",
                "}"};
    }

}
